@@ -78,7 +78,7 @@ class Directory(FileSystemObject, Accumulator, SettingsAware):
 		'basename': sort_by_basename,
 		'size': lambda path: -path.size,
 		'mtime': lambda path: -(path.stat and path.stat.st_mtime or 1),
-		'type': lambda path: path.mimetype,
+		'type': lambda path: path.mimetype or '',
 	}
 
 	def __init__(self, path, **kw):
